@@ -5,9 +5,10 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"slices"
 	"strings"
 
-	incus "github.com/lxc/incus/shared/util"
+	incus "github.com/lxc/incus/v6/shared/util"
 
 	"github.com/lxc/distrobuilder/shared"
 )
@@ -20,16 +21,6 @@ type debootstrap struct {
 func (s *debootstrap) Run() error {
 	var args []string
 
-	distro := strings.ToLower(s.definition.Image.Distribution)
-	release := strings.ToLower(s.definition.Image.Release)
-
-	// Enable merged /usr by default, and disable it for certain distros/releases
-	if distro == "ubuntu" && incus.ValueInSlice(release, []string{"xenial", "bionic"}) || distro == "mint" && incus.ValueInSlice(release, []string{"tara", "tessa", "tina", "tricia", "ulyana"}) || distro == "devuan" {
-		args = append(args, "--no-merged-usr")
-	} else {
-		args = append(args, "--merged-usr")
-	}
-
 	os.RemoveAll(s.rootfsDir)
 
 	if s.definition.Source.Variant != "" {
@@ -44,6 +35,11 @@ func (s *debootstrap) Run() error {
 		args = append(args, "--no-check-gpg")
 	}
 
+	if s.definition.Image.Distribution == "devuan" && slices.Contains([]string{"beowulf", "chimaera"}, s.definition.Image.Release) {
+		// Workaround for debootstrap attempting to fetch non-existent usr-is-merged.
+		args = append(args, "--exclude=usr-is-merged")
+	}
+
 	earlyPackagesInstall := s.definition.GetEarlyPackages("install")
 	earlyPackagesRemove := s.definition.GetEarlyPackages("remove")
 
