@@ -15,13 +15,11 @@ func (s *nixos) Run() error {
 	hydraProject := "nixos"
 
 	hydraJobset := fmt.Sprintf("release-%s", s.definition.Image.Release)
-	releaseAttr := "lxdContainerImage"
-	hydraBuildProduct := "system-tarball"
+	releaseAttr := "incusContainerImage"
+	hydraBuildProduct := "squashfs-image"
 
 	if s.definition.Image.Release == "unstable" {
 		hydraJobset = "trunk-combined"
-		releaseAttr = "incusContainerImage"
-		hydraBuildProduct = "squashfs-image"
 	}
 
 	hydraJob := fmt.Sprintf("nixos.%s.%s-linux", releaseAttr, s.definition.Image.ArchitectureMapped)
