@@ -10,9 +10,9 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/antchfx/htmlquery"
 	incus "github.com/lxc/incus/v6/shared/util"
 	"golang.org/x/sys/unix"
-	"gopkg.in/antchfx/htmlquery.v1"
 
 	"github.com/lxc/distrobuilder/shared"
 )
@@ -49,9 +49,10 @@ func (s *oraclelinux) Run() error {
 			latestUpdate = fmt.Sprintf("u%d", i)
 
 			if s.definition.Image.Release == "9" {
-				if s.architecture == "x86_64" {
+				switch s.architecture {
+				case "x86_64":
 					fname = fmt.Sprintf("OracleLinux-R9-U%d-%s-boot.iso", i, s.architecture)
-				} else if s.architecture == "aarch64" {
+				case "aarch64":
 					fname = fmt.Sprintf("OracleLinux-R9-U%d-%s-dvd.iso", i, s.architecture)
 				}
 			}
@@ -140,7 +141,7 @@ func (s *oraclelinux) unpackISO(latestUpdate, filePath, rootfsDir string) error
 	tempRootDir := filepath.Join(s.cacheDir, "rootfs")
 
 	for _, dir := range []string{isoDir, squashfsDir, roRootDir} {
-		err := os.MkdirAll(dir, 0755)
+		err := os.MkdirAll(dir, 0o755)
 		if err != nil {
 			return fmt.Errorf("Failed to create %q: %w", dir, err)
 		}
@@ -374,11 +375,12 @@ EOF
 func (s *oraclelinux) getISO(URL string, architecture string) (string, error) {
 	var re *regexp.Regexp
 
-	if architecture == "x86_64" {
+	switch architecture {
+	case "x86_64":
 		re = regexp.MustCompile(fmt.Sprintf("%s-boot(-\\d{8})?.iso", architecture))
-	} else if architecture == "aarch64" {
+	case "aarch64":
 		re = regexp.MustCompile(fmt.Sprintf("%s-boot-uek(-\\d{8})?.iso", architecture))
-	} else {
+	default:
 		return "", fmt.Errorf("Unsupported architecture %q", architecture)
 	}
 
